@@ -20,8 +20,6 @@ from keras_tuner.api_export import keras_tuner_export
 from keras_tuner.engine.hypermodel import HyperModel
 from keras_tuner.engine.hyperparameters import HyperParameter
 from keras_tuner.engine.hyperparameters import HyperParameters
-from keras_tuner.engine.logger import CloudLogger
-from keras_tuner.engine.logger import Logger
 from keras_tuner.engine.objective import Objective
 from keras_tuner.engine.oracle import Oracle
 from keras_tuner.engine.oracle import synchronized
@@ -35,10 +33,4 @@ from keras_tuner.utils import check_tf_version
 
 check_tf_version()
 
-
-class Version(str):
-    __name__ = "Version"
-
-
-__version__ = Version("1.2.1")
-keras_tuner_export("keras_tuner.__version__")(__version__)
+__version__ = "1.3.1"
