@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import tensorflow as tf
-import tensorflow.keras as keras
+from tensorflow import keras
 from tensorflow.keras import layers
 
 from keras_tuner.api_export import keras_tuner_export
@@ -53,11 +53,13 @@ class HyperXception(hypermodel.HyperModel):
     ):
         super().__init__(**kwargs)
         if include_top and classes is None:
-            raise ValueError("You must specify `classes` when " "`include_top=True`")
+            raise ValueError(
+                "You must specify `classes` when `include_top=True`"
+            )
 
         if input_shape is None and input_tensor is None:
             raise ValueError(
-                "You must specify either `input_shape` " "or `input_tensor`."
+                "You must specify either `input_shape` or `input_tensor`."
             )
 
         self.include_top = include_top
@@ -91,14 +93,18 @@ class HyperXception(hypermodel.HyperModel):
         )
 
         # Separable convs.
-        sep_num_filters = hp.Int("sep_num_filters", 128, 768, step=128, default=256)
+        sep_num_filters = hp.Int(
+            "sep_num_filters", 128, 768, step=128, default=256
+        )
         num_residual_blocks = hp.Int("num_residual_blocks", 2, 8, default=4)
         for _ in range(num_residual_blocks):
             x = residual(
                 x, sep_num_filters, activation=activation, max_pooling=False
             )
         # Exit flow.
-        x = residual(x, 2 * sep_num_filters, activation=activation, max_pooling=True)
+        x = residual(
+            x, 2 * sep_num_filters, activation=activation, max_pooling=True
+        )
 
         pooling = hp.Choice("pooling", ["avg", "flatten", "max"])
         if pooling == "flatten":
@@ -150,8 +156,6 @@ def sep_conv(x, num_filters, kernel_size=(3, 3), activation="relu"):
         )(x)
         x = layers.BatchNormalization()(x)
         x = layers.Activation("relu")(x)
-    else:
-        ValueError(f"Unknown activation function: {activation}")
     return x
 
 
@@ -166,7 +170,10 @@ def residual(
     "Residual block."
     if max_pooling:
         res = layers.Conv2D(
-            num_filters, kernel_size=(1, 1), strides=pool_strides, padding="same"
+            num_filters,
+            kernel_size=(1, 1),
+            strides=pool_strides,
+            padding="same",
         )(x)
     elif num_filters != keras.backend.int_shape(x)[-1]:
         res = layers.Conv2D(num_filters, kernel_size=(1, 1), padding="same")(x)
@@ -176,7 +183,9 @@ def residual(
     x = sep_conv(x, num_filters, kernel_size, activation)
     x = sep_conv(x, num_filters, kernel_size, activation)
     if max_pooling:
-        x = layers.MaxPooling2D(kernel_size, strides=pool_strides, padding="same")(x)
+        x = layers.MaxPooling2D(
+            kernel_size, strides=pool_strides, padding="same"
+        )(x)
 
     x = layers.add([x, res])
     return x
@@ -196,13 +205,14 @@ def conv(x, num_filters, kernel_size=(3, 3), activation="relu", strides=(2, 2)):
         )(x)
     elif activation == "relu":
         x = layers.Conv2D(
-            num_filters, kernel_size, strides=strides, padding="same", use_bias=False
+            num_filters,
+            kernel_size,
+            strides=strides,
+            padding="same",
+            use_bias=False,
         )(x)
         x = layers.BatchNormalization()(x)
         x = layers.Activation("relu")(x)
-    else:
-        msg = f"Unknown activation function: {activation}"
-        ValueError(msg)
     return x
 
 
@@ -222,7 +232,4 @@ def dense(x, dims, activation="relu", batchnorm=True, dropout_rate=0):
             x = layers.BatchNormalization()(x)
         if dropout_rate:
             x = layers.Dropout(dropout_rate)(x)
-    else:
-        msg = f"Unknown activation function: {activation}"
-        ValueError(msg)
     return x
