@@ -45,11 +45,10 @@ class OracleServicer(service_pb2_grpc.OracleServicer):
         return service_pb2.CreateTrialResponse(trial=trial.to_proto())
 
     def UpdateTrial(self, request, context):
-        status = self.oracle.update_trial(
+        trial = self.oracle.update_trial(
             request.trial_id, request.metrics, step=request.step
         )
-        status_proto = trial_module.TrialStatus.to_proto(status)
-        return service_pb2.UpdateTrialResponse(status=status_proto)
+        return service_pb2.UpdateTrialResponse(trial=trial.to_proto())
 
     def EndTrial(self, request, context):
         trial = trial_module.Trial.from_proto(request.trial)
@@ -82,13 +81,14 @@ def start_server(oracle):
 
         if oracle_servicer.stop_triggered:
             while oracle.ongoing_trials:
-                time.sleep(10)
+                time.sleep(10)  # pragma: no cover
 
             print(
                 "Oracle server on chief is exiting in 40s."
                 "The chief will go on with post-search code."
             )
-            # Wait for another 30s for all the subsequent calls from workers to come
+            # Wait for another 30s for all the subsequent calls from workers to
+            # come
             time.sleep(30)
             server.stop(10)
             break
