@@ -68,7 +68,8 @@ class OracleClient:
 
     def create_trial(self, tuner_id):
         response = self.stub.CreateTrial(
-            service_pb2.CreateTrialRequest(tuner_id=tuner_id), wait_for_ready=True
+            service_pb2.CreateTrialRequest(tuner_id=tuner_id),
+            wait_for_ready=True,
         )
         return trial_module.Trial.from_proto(response.trial)
 
@@ -82,8 +83,8 @@ class OracleClient:
                 wait_for_ready=True,
             )
             if not self.multi_worker:
-                return trial_module.TrialStatus.from_proto(response.status)
-        return "RUNNING"
+                return trial_module.Trial.from_proto(response.trial)
+        return trial_module.Trial(self.get_space(), status="RUNNING")
 
     def end_trial(self, trial):
         if self.should_report:
@@ -103,4 +104,6 @@ class OracleClient:
             service_pb2.GetBestTrialsRequest(num_trials=num_trials),
             wait_for_ready=True,
         )
-        return [trial_module.Trial.from_proto(trial) for trial in response.trials]
+        return [
+            trial_module.Trial.from_proto(trial) for trial in response.trials
+        ]
