@@ -69,11 +69,10 @@ class BaseTuner(stateful.Stateful):
         directory: A string, the relative path to the working directory.
         project_name: A string, the name to use as prefix for files saved by
             this Tuner.
-        logger: Optional instance of `kerastuner.Logger` class for
-            streaming logs for monitoring.
         overwrite: Boolean, defaults to `False`. If `False`, reloads an
             existing project of the same name if one is found. Otherwise,
             overwrites the project.
+        **kwargs: Arguments for backward compatibility.
 
     Attributes:
         remaining_trials: Number of trials remaining, `None` if `max_trials` is
@@ -86,8 +85,8 @@ class BaseTuner(stateful.Stateful):
         hypermodel=None,
         directory=None,
         project_name=None,
-        logger=None,
         overwrite=False,
+        **kwargs,
     ):
         if not isinstance(oracle, oracle_module.Oracle):
             raise ValueError(
@@ -95,6 +94,22 @@ class BaseTuner(stateful.Stateful):
                 f"Received: oracle={oracle} (of type ({type(oracle)})."
             )
 
+        logger = kwargs.pop("logger", None)
+        if logger is not None:
+            warnings.warn(
+                "The `logger` argument in `BaseTuner.__init__() is "
+                "no longer supported and will be ignored.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        self.logger = logger
+
+        if len(kwargs) > 0:
+            raise ValueError(
+                f"Unrecognized arguments {list(kwargs.keys())} "
+                "for `BaseTuner.__init__()`."
+            )
+
         self.oracle = oracle
         self.hypermodel = hm_module.get_hypermodel(hypermodel)
 
@@ -103,8 +118,6 @@ class BaseTuner(stateful.Stateful):
         self.project_name = project_name or "untitled_project"
         self.oracle._set_project_dir(self.directory, self.project_name)
 
-        self.logger = logger
-
         if overwrite and tf.io.gfile.exists(self.project_dir):
             tf.io.gfile.rmtree(self.project_dir)
 
@@ -113,7 +126,9 @@ class BaseTuner(stateful.Stateful):
 
         # Reloading state.
         if not overwrite and tf.io.gfile.exists(self._get_tuner_fname()):
-            tf.get_logger().info(f"Reloading Tuner from {self._get_tuner_fname()}")
+            tf.get_logger().info(
+                f"Reloading Tuner from {self._get_tuner_fname()}"
+            )
             self.reload()
         else:
             # Only populate initial space if not reloading.
@@ -127,7 +142,8 @@ class BaseTuner(stateful.Stateful):
             # Proxies requests to the chief oracle.
             self.oracle = oracle_client.OracleClient(self.oracle)
 
-        # In parallel tuning, everything below in __init__() is for workers only.
+        # In parallel tuning, everything below in __init__() is for workers
+        # only.
         # Logs etc
         self._display = tuner_utils.Display(oracle=self.oracle)
 
@@ -277,8 +293,8 @@ class BaseTuner(stateful.Stateful):
             trial_id: The ID of the `Trial` corresponding to this Model.
             model: The trained model.
             step: Integer, for models that report intermediate results to the
-                `Oracle`, the step the saved file correspond to. For example, for
-                Keras models this is the number of epochs trained.
+                `Oracle`, the step the saved file correspond to. For example,
+                for Keras models this is the number of epochs trained.
         """
         raise NotImplementedError
 
@@ -304,8 +320,6 @@ class BaseTuner(stateful.Stateful):
         Args:
             trial: A `Trial` instance.
         """
-        if self.logger:
-            self.logger.register_trial(trial.trial_id, trial.get_state())
         self._display.on_trial_begin(self.oracle.get_trial(trial.trial_id))
 
     def on_trial_end(self, trial):
@@ -314,10 +328,6 @@ class BaseTuner(stateful.Stateful):
         Args:
             trial: A `Trial` instance.
         """
-        # Send status to Logger
-        if self.logger:
-            self.logger.report_trial_state(trial.trial_id, trial.get_state())
-
         self.oracle.end_trial(trial)
         # Display needs the updated trial scored by the Oracle.
         self._display.on_trial_end(self.oracle.get_trial(trial.trial_id))
@@ -325,13 +335,11 @@ class BaseTuner(stateful.Stateful):
 
     def on_search_begin(self):
         """Called at the beginning of the `search` method."""
-        if self.logger:
-            self.logger.register_tuner(self.get_state())
+        pass
 
     def on_search_end(self):
         """Called at the end of the `search` method."""
-        if self.logger:
-            self.logger.exit()
+        pass
 
     def get_best_models(self, num_models=1):
         """Returns the best model(s), as determined by the objective.
@@ -371,7 +379,9 @@ class BaseTuner(stateful.Stateful):
         Returns:
             List of `HyperParameter` objects sorted from the best to the worst.
         """
-        return [t.hyperparameters for t in self.oracle.get_best_trials(num_trials)]
+        return [
+            t.hyperparameters for t in self.oracle.get_best_trials(num_trials)
+        ]
 
     def search_space_summary(self, extended=False):
         """Print search space summary.
@@ -408,6 +418,7 @@ class BaseTuner(stateful.Stateful):
 
         best_trials = self.oracle.get_best_trials(num_trials)
         for trial in best_trials:
+            print()
             trial.summary()
 
     @property
@@ -427,7 +438,9 @@ class BaseTuner(stateful.Stateful):
 
     def _is_worker(self):
         """Return true only if in parallel tuning and is a worker tuner."""
-        return dist_utils.has_chief_oracle() and not dist_utils.is_chief_oracle()
+        return (
+            dist_utils.has_chief_oracle() and not dist_utils.is_chief_oracle()
+        )
 
     def save(self):
         """Saves this object to its project directory."""
