@@ -13,8 +13,12 @@
 # limitations under the License.
 "HyperModel base class."
 
+from keras_tuner import errors
+from keras_tuner.api_export import keras_tuner_export
 
-class HyperModel(object):
+
+@keras_tuner_export("keras_tuner.HyperModel")
+class HyperModel:
     """Defines a search space of models.
 
     A search space is a collection of models. The `build` function will build
@@ -110,6 +114,9 @@ class HyperModel(object):
             hp = hp.copy()
         return self._build(hp, *args, **kwargs)
 
+    def declare_hyperparameters(self, hp):
+        pass
+
     def fit(self, hp, model, *args, **kwargs):
         """Train the model.
 
@@ -141,7 +148,7 @@ class DefaultHyperModel(HyperModel):
     """Produces HyperModel from a model building function."""
 
     def __init__(self, build, name=None, tunable=True):
-        super(DefaultHyperModel, self).__init__(name=name)
+        super().__init__(name=name)
         self.build = build
 
 
@@ -154,7 +161,7 @@ def get_hypermodel(hypermodel):
         return hypermodel
 
     if not callable(hypermodel):
-        raise ValueError(
+        raise errors.FatalValueError(
             "The `hypermodel` argument should be either "
             "a callable with signature `build(hp)` returning a model, "
             "or an instance of `HyperModel`."
