@@ -67,7 +67,9 @@ class MetricObservation:
         return f"MetricObservation(value={self.value}, step={self.step})"
 
     def to_proto(self):
-        return keras_tuner_pb2.MetricObservation(value=self.value, step=self.step)
+        return keras_tuner_pb2.MetricObservation(
+            value=self.value, step=self.step
+        )
 
     @classmethod
     def from_proto(cls, proto):
@@ -104,7 +106,9 @@ class MetricHistory:
         values = [obs.mean() for obs in self._observations.values()]
         if not values:
             return None
-        return np.nanmin(values) if self.direction == "min" else np.nanmax(values)
+        return (
+            np.nanmin(values) if self.direction == "min" else np.nanmax(values)
+        )
 
     def get_best_step(self):
         best_value = self.get_best_value()
@@ -157,7 +161,10 @@ class MetricHistory:
     def from_config(cls, config):
         instance = cls(config["direction"])
         instance.set_history(
-            [MetricObservation.from_config(obs) for obs in config["observations"]]
+            [
+                MetricObservation.from_config(obs)
+                for obs in config["observations"]
+            ]
         )
         return instance
 
@@ -335,24 +342,28 @@ def infer_metric_direction(metric):
         try:
             if (
                 "use_legacy_format"
-                in inspect.getargspec(keras.metrics.deserialize).args
+                in inspect.getfullargspec(keras.metrics.deserialize).args
             ):
-                metric = keras.metrics.deserialize(
+                metric = keras.metrics.deserialize(  # pragma: no cover
                     metric_name, use_legacy_format=True
                 )
             else:
-                metric = keras.metrics.deserialize(metric_name)
+                metric = keras.metrics.deserialize(  # pragma: no cover
+                    metric_name
+                )
         except ValueError:
             try:
                 if (
                     "use_legacy_format"
-                    in inspect.getargspec(keras.losses.deserialize).args
+                    in inspect.getfullargspec(keras.losses.deserialize).args
                 ):
-                    metric = keras.losses.deserialize(
+                    metric = keras.losses.deserialize(  # pragma: no cover
                         metric_name, use_legacy_format=True
                     )
                 else:
-                    metric = keras.losses.deserialize(metric_name)
+                    metric = keras.losses.deserialize(  # pragma: no cover
+                        metric_name
+                    )
             except Exception:
                 # Direction can't be inferred.
                 return None
@@ -361,7 +372,7 @@ def infer_metric_direction(metric):
     if isinstance(metric, (keras.metrics.Metric, keras.losses.Loss)):
         name = metric.__class__.__name__
         if name == "MeanMetricWrapper":
-            name = metric._fn.__name__
+            name = metric._fn.__name__  # pragma: no cover
     else:
         name = metric.__name__
 
