@@ -12,9 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from keras_tuner.api_export import keras_tuner_export
 from keras_tuner.engine import metrics_tracking
 
 
+@keras_tuner_export("keras_tuner.Objective")
 class Objective:
     """The objective for optimization during tuning.
 
@@ -72,6 +74,9 @@ class Objective:
     def __eq__(self, obj):
         return self.name == obj.name and self.direction == obj.direction
 
+    def __str__(self):
+        return f'Objective(name="{self.name}", direction="{self.direction}")'
+
 
 class DefaultObjective(Objective):
     """Default objective to minimize if not provided by the user."""
@@ -115,6 +120,13 @@ class MultiObjective(Objective):
             obj.objectives, key=lambda x: x.name
         )
 
+    def __str__(self):
+        return (
+            "Multi"
+            + super().__str__()
+            + f": [{', '.join(map(lambda x: str(x), self.objectives))}]"
+        )
+
 
 def create_objective(objective):
     if objective is None:
@@ -124,7 +136,7 @@ def create_objective(objective):
     if isinstance(objective, Objective):
         return objective
     if not isinstance(objective, str):
-        raise ValueError(
+        raise TypeError(
             "`objective` not understood, expected str or "
             f"`Objective` object, found: {objective}"
         )
