@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import pytest
+
 import keras_tuner
 from keras_tuner.engine import objective
 
@@ -29,20 +31,33 @@ def test_create_objective_with_objective():
 
 def test_create_objective_with_multi_objective():
     obj = objective.create_objective(
-        [keras_tuner.Objective("score", "max"), keras_tuner.Objective("loss", "min")]
+        [
+            keras_tuner.Objective("score", "max"),
+            keras_tuner.Objective("loss", "min"),
+        ]
     )
     assert isinstance(obj, objective.MultiObjective)
-    assert obj.objectives[0].name == "score" and obj.objectives[0].direction == "max"
-    assert obj.objectives[1].name == "loss" and obj.objectives[1].direction == "min"
+    assert (
+        obj.objectives[0].name == "score"
+        and obj.objectives[0].direction == "max"
+    )
+    assert (
+        obj.objectives[1].name == "loss"
+        and obj.objectives[1].direction == "min"
+    )
 
 
 def test_create_objective_with_multi_str():
     obj = objective.create_objective(["accuracy", "loss"])
     assert isinstance(obj, objective.MultiObjective)
     assert (
-        obj.objectives[0].name == "accuracy" and obj.objectives[0].direction == "max"
+        obj.objectives[0].name == "accuracy"
+        and obj.objectives[0].direction == "max"
+    )
+    assert (
+        obj.objectives[1].name == "loss"
+        and obj.objectives[1].direction == "min"
     )
-    assert obj.objectives[1].name == "loss" and obj.objectives[1].direction == "min"
 
 
 def test_objective_better_than_max():
@@ -109,3 +124,22 @@ def test_multi_objective_has_value():
     obj = objective.create_objective(["loss", "accuracy"])
     assert obj.has_value({"loss": 1.0, "accuracy": 1.0, "mse": 2.0})
     assert not obj.has_value({"accuracy": 1.0, "mse": 2.0})
+
+
+def test_objective_to_str():
+    obj = objective.Objective(name="accuracy", direction="min")
+    assert str(obj) == 'Objective(name="accuracy", direction="min")'
+
+
+def test_multi_objective_to_str():
+    obj = objective.create_objective(["loss", "accuracy"])
+    assert (
+        str(obj) == 'MultiObjective(name="multi_objective", direction="min"): '
+        '[Objective(name="loss", direction="min"), '
+        'Objective(name="accuracy", direction="max")]'
+    )
+
+
+def test_unknown_objective_type_error():
+    with pytest.raises(TypeError, match="not understood, expected str"):
+        objective.create_objective([3, "accuracy"])
