@@ -16,7 +16,6 @@
 
 import collections
 import hashlib
-import json
 import os
 import random
 import threading
@@ -41,8 +40,9 @@ LOCKS = collections.defaultdict(lambda: threading.Lock())
 THREADS = collections.defaultdict(lambda: None)
 
 
+@keras_tuner_export("keras_tuner.synchronized")
 def synchronized(func, *args, **kwargs):
-    """Decorator to synchronize the multi-threaded calls to a `Oracle` functions.
+    """Decorator to synchronize the multi-threaded calls to `Oracle` functions.
 
     In parallel tuning, there may be concurrent gRPC calls from multiple threads
     to the `Oracle` methods like `create_trial()`, `update_trial()`, and
@@ -91,7 +91,9 @@ def synchronized(func, *args, **kwargs):
         # For backward compatible with the old end_trial signature:
         # def end_trial(self, trial_id, status="COMPLETED"):
         if func.__name__ == "end_trial" and (
-            "trial_id" in kwargs or "status" in kwargs or isinstance(args[1], str)
+            "trial_id" in kwargs
+            or "status" in kwargs
+            or isinstance(args[1], str)
         ):
             args, kwargs = backward_compatible_end_trial(*args, **kwargs)
 
@@ -155,11 +157,12 @@ class Oracle(stateful.Stateful):
             Defaults to True.
         seed: Int. Random seed.
         max_retries_per_trial: Integer. Defaults to 0. The maximum number of
-            times to retry a `Trial` if the trial crashed or the results are invalid.
-        max_consecutive_failed_trials: Integer. Defaults to 3. The maximum number of
-            consecutive failed `Trial`s. When this number is reached, the search
-            will be stopped. A `Trial` is marked as failed when none of the
-            retries succeeded.
+            times to retry a `Trial` if the trial crashed or the results are
+            invalid.
+        max_consecutive_failed_trials: Integer. Defaults to 3. The maximum
+            number of consecutive failed `Trial`s. When this number is reached,
+            the search will be stopped. A `Trial` is marked as failed when none
+            of the retries succeeded.
     """
 
     def __init__(
@@ -261,7 +264,8 @@ class Oracle(stateful.Stateful):
 
     def _score_trial(self, trial):
         warnings.warn(
-            "The `_score_trial` method is deprecated, please use `score_trial`.",
+            "The `_score_trial` method is deprecated, "
+            "please use `score_trial`.",
             DeprecationWarning,
         )
         self.score_trial(trial)
@@ -367,7 +371,7 @@ class Oracle(stateful.Stateful):
             trial.metrics.update(metric_name, metric_value, step=step)
         self._save_trial(trial)
         # TODO: To signal early stopping, set Trial.status to "STOPPED".
-        return trial.status
+        return trial
 
     def _check_consecutive_failures(self):
         # For thread safety, check all trials for consecutive failures.
@@ -381,7 +385,8 @@ class Oracle(stateful.Stateful):
             if consecutive_failures == self.max_consecutive_failed_trials:
                 raise RuntimeError(
                     "Number of consecutive failures excceeded the limit "
-                    f"of {self.max_consecutive_failed_trials}.\n" + trial.message
+                    f"of {self.max_consecutive_failed_trials}.\n"
+                    + trial.message
                 )
 
     @synchronized
@@ -480,7 +485,8 @@ class Oracle(stateful.Stateful):
 
         if new_hps and not self.allow_new_entries:
             raise RuntimeError(
-                f"`allow_new_entries` is `False`, but found new entries {new_hps}"
+                "`allow_new_entries` is `False`, "
+                f"but found new entries {new_hps}"
             )
         if not self.tune_new_entries:
             # New entries should always use the default value.
@@ -504,11 +510,20 @@ class Oracle(stateful.Stateful):
             key=lambda trial: trial.score,
             reverse=self.objective.direction == "max",
         )
+
+        if len(sorted_trials) < num_trials:
+            sorted_trials = sorted_trials + [
+                t
+                for t in self.trials.values()
+                if t.status != trial_module.TrialStatus.COMPLETED
+            ]
         return sorted_trials[:num_trials]
 
     def remaining_trials(self):
         return (
-            self.max_trials - len(self.trials.items()) if self.max_trials else None
+            self.max_trials - len(self.trials.items())
+            if self.max_trials
+            else None
         )
 
     def get_state(self):
@@ -573,10 +588,7 @@ class Oracle(stateful.Stateful):
             os.path.join(self._project_dir, "trial_*", "trial.json")
         )
         for fname in trial_fnames:
-            with tf.io.gfile.GFile(fname, "r") as f:
-                trial_data = f.read()
-            trial_state = json.loads(trial_data)
-            trial = trial_module.Trial.from_state(trial_state)
+            trial = trial_module.Trial.load(fname)
             self.trials[trial.trial_id] = trial
         try:
             super().reload(self._get_oracle_fname())
@@ -603,10 +615,10 @@ class Oracle(stateful.Stateful):
         return hashlib.sha256(s.encode("utf-8")).hexdigest()[:32]
 
     def _check_objective_found(self, metrics):
-        if isinstance(self.objective, obj_module.Objective):
-            objective_names = [self.objective.name]
+        if isinstance(self.objective, obj_module.MultiObjective):
+            objective_names = list(self.objective.name_to_direction.keys())
         else:
-            objective_names = [obj.name for obj in self.objective]
+            objective_names = [self.objective.name]
         for metric_name in metrics.keys():
             if metric_name in objective_names:
                 objective_names.remove(metric_name)
@@ -671,10 +683,12 @@ class Oracle(stateful.Stateful):
 
         # In case of new hp appeared, remove the old hash value.
         old_hash_value = self._id_to_hash[trial.trial_id]
-        if old_hash_value is None:
+        if old_hash_value != new_hash_value:
             self._id_to_hash[trial.trial_id] = new_hash_value
-        elif old_hash_value != new_hash_value:
-            self._tried_so_far.remove(old_hash_value)
+            # Check before removing. If this is a retry run, the old value may
+            # have been removed already.
+            if old_hash_value in self._tried_so_far:
+                self._tried_so_far.remove(old_hash_value)
 
 
 def _maybe_infer_direction_from_objective(objective, metric_name):
